@@ -216,11 +216,15 @@ encode_images = function(x) {
   # only process prose lines and not code blocks
   if (length(p <- prose_index(x)) == 0) return(x)
   xp = x[p]
-  # opening and closing tags of images
-  r1 = c('!\\[.*?\\]\\(', '<img .*?src\\s*=\\s*"', '^background-image: url\\("?')
-  r2 = c('\\)',           '".*?/>',                '"?\\)')
-  regs = paste0('(?<!`)(', r1, ')(.*?)(', r2, ')(?!`)')
-  for (r in regs) xp = encode_reg(r, xp)
+  # opening and closing tags of images and audio files
+  rs = matrix(c(
+    '!\\[.*?\\]\\(', '\\)',
+    '<img .*?src\\s*=\\s*"', '".*?/>',
+    '<source .*?src\\s*=\\s*"',  '".*?>',
+    '^background-image: url\\("?', '"?\\)'
+  ), 2)
+  rs = paste0('(?<!`)(', rs[1, ], ')(.*?)(', rs[2, ], ')(?!`)')
+  for (r in rs) xp = encode_reg(r, xp)
   x[p] = xp
   x
 }
